.. Setup build dependency
.. include:: ../mons/commands/main.py
   :end-line: 0

.. click:: mons.mons:cli
   :prog: mons
   :nested: full
   :maxdepth: 1

.. |full_reference-mods| replace:: :doc:`Full Reference</mods>`
